function jf45irv30sec(input)
# jonfields45@gmail.com
# input.wav is the sample to be processed, pickup left, mic right
diary logfile;
diary on;
# IR generation:
ss = (2^17); # ~3 second segment size for analysis
nstep = 1; # segment step ~3 seconds
nstart = 3; # index into .wav in segments, ~6 seconds
nlast = 9; # up to 7 segments checked for suitable SNR & no clip 
count = 0; # initialize good segment count
nzcount = 0; # initialize near zero count
accirfftnnz = zeros(ss,1); # initialize no near zero IR accumulator
window = (.42-.5*cos(2*pi*(0:ss-1)/(ss-1))+.08*cos(4*pi*(0:ss-1)/(ss-1)))';
#
for n = nstart:nstep:nlast # process segments
     start = (((n-1) * ss) + 1);
     finish = (n * ss);
     [s,fs] = audioread([input,'.wav'],[start, finish]); # load segment
     smax = max(max(s));
     clip = (smax > 0.999); # check for clipping
     toolow = (smax < 0.178); # more than 15 dB down
     if (clip == 0 && toolow == 0 && count < 4) # per segment IR
          pickup = s(:,1) .* window;
          mic = s(:,2) .* window;
          pupfft = fft(pickup);
          micfft = fft(mic);
          pupfftnnz = pupfft;
          micfftnnz = micfft;
          nearzero = 10^(-65/20)*abs(max(pupfft)); # ~0 is -65dB from peak
          for m = 1:1:ss
               if (abs(pupfft(m)) < nearzero) # Check near 0 div
                    nzcount = nzcount + 1; # Count near 0s (pos & neg freq)
                    pupfftnnz(m) = 1; # erase near zero
                    micfftnnz(m) = 1; # erase near zero
               end   
          end
          irfftnnz = micfftnnz ./ pupfftnnz; # segment IR=FFT(mic)/FFT(PUP)
          accirfftnnz = accirfftnnz + irfftnnz; # accumulate segment IRs
          count = count + 1; # increment processed segment count
     end
end
if(count==0)
    ['Zero Segments Processed due to Clip/Min errors']
    return;
end
#
irnnz = ifft(accirfftnnz/count); # calc average IR over processed segments
ir2048nnz = irnnz(1:2048); # truncate to 2048
#
avgnzcount = nzcount / (count*2); # pos freq avg near zero count per seg
['Processed Segments = ',num2str(count)] 
['Average Near Zero per Segment = ',num2str(avgnzcount)]
['Sample Rate = ',num2str(fs)]
#
filename = ['jf45ir ',input,'.wav'];
audiowrite(filename,ir2048nnz,fs); # write IR
#
filename = ['jf45ir1024 ',input,'.wav'];
audiowrite(filename,ir2048nnz(1:1024),fs); # write IR
#
fftir2048nnz = fft(ir2048nnz); # FFT final IR for frequency plot
y = 20*log(abs(fftir2048nnz(2:1024))); # print frequency plot
x = fs*(1:1023)/2048;
semilogx(x,y);
xlim([20 15000]);
xlabel('Hz');
filename = ['FFTjf45ir ',input,'.jpg'];
ylabel([filename,' dB']);
print(filename,'-djpeg');
#
# 50/50 IR generation
irrms=(sum(ir2048nnz.*ir2048nnz))^0.5;
ir2048nnz5050=(ir2048nnz*0.5);
ir2048nnz5050(1)=ir2048nnz5050(1)+(irrms*0.5);
#
filename = ['jf45ir5050 ',input,'.wav'];
audiowrite(filename,ir2048nnz5050,fs); # write IR
#
filename = ['jf45ir50501024 ',input,'.wav'];
audiowrite(filename,ir2048nnz5050(1:1024),fs); # write IR
#
# 75/25
ir2048nnz7525=(ir2048nnz*0.75);
ir2048nnz7525(1)=ir2048nnz7525(1)+(irrms*0.25);
#
filename = ['jf45ir7525 ',input,'.wav'];
audiowrite(filename,ir2048nnz7525,fs); # write IR
#
filename = ['jf45ir75251024 ',input,'.wav'];
audiowrite(filename,ir2048nnz7525(1:1024),fs); # write IR
#
# 60/40
ir2048nnz6040=(ir2048nnz*0.6);
ir2048nnz6040(1)=ir2048nnz6040(1)+(irrms*0.4);
#
filename = ['jf45ir6040 ',input,'.wav'];
audiowrite(filename,ir2048nnz6040,fs); # write IR
#
filename = ['jf45ir60401024 ',input,'.wav'];
audiowrite(filename,ir2048nnz6040(1:1024),fs); # write IR
# 40/60
ir2048nnz4060=(ir2048nnz*0.4);
ir2048nnz4060(1)=ir2048nnz4060(1)+(irrms*0.6);
#
filename = ['jf45ir4060 ',input,'.wav'];
audiowrite(filename,ir2048nnz4060,fs); # write IR
#
filename = ['jf45ir40601024 ',input,'.wav'];
audiowrite(filename,ir2048nnz4060(1:1024),fs); # write IR
# 25/75
ir2048nnz2575=(ir2048nnz*0.25);
ir2048nnz2575(1)=ir2048nnz2575(1)+(irrms*0.75);
#
filename = ['jf45ir2575 ',input,'.wav'];
audiowrite(filename,ir2048nnz2575,fs); # write IR
#
filename = ['jf45ir25751024 ',input,'.wav'];
audiowrite(filename,ir2048nnz2575(1:1024),fs); # write IR
#
close;
diary off;
